@@ -24,13 +24,13 @@ def clean_copy_cli(source, destination, quiet, ignore_spec, include_parent_ignor
 
     parent_rules = []
     if include_parent_ignore:
-        parent_rules = get_gitignore_rules(source.parent / ".copyignore")
+        parent_rules = get_gitignore_rules(source.parent / ignore_spec)
 
     unignored_files = get_unignored_files(
         root_path=source,
         folder_path=None,
         parent_rules=parent_rules,
-        ignore_spec=".copyignore",
+        ignore_spec=ignore_spec,
     )
     copy_count, file_size = copy_files(source, destination, unignored_files=unignored_files)
     click.echo(f"Copied {copy_count} files ({file_size} MB) from {source} to {destination}")
